@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -29,13 +29,11 @@ use strict;
 use Gtk2;
 
 #Gettext and filename parsing
-use POSIX qw/setlocale strftime/;
+use POSIX qw/setlocale/;
 use Locale::gettext;
 
-#define constants
-#--------------------------------------
-use constant TRUE  => 1;
-use constant FALSE => 0;
+#Glib
+use Glib qw/TRUE FALSE/; 
 
 #--------------------------------------
 
@@ -44,7 +42,7 @@ sub new {
 	my $class = shift;
 
 	#constructor
-	my $self = { _shutter_root => shift };
+	my $self = { _shutter_root => shift, _mainwindow => shift, _appname => shift, _version => shift, _rev => shift, _pid => shift };
 
 	#vars
 	$self->{_debug_cparam}           = FALSE;
@@ -52,10 +50,11 @@ sub new {
 	$self->{_min_cparam}             = FALSE;
 	$self->{_disable_systray_cparam} = FALSE;
 	$self->{_start_with}             = undef;
-	$self->{_mainwindow}             = undef;
 
-	#gettext init
+	#Set LC_NUMERIC to C to prevent decimal commas (or anything else)
+	setlocale(LC_NUMERIC, "C");	
 	setlocale( LC_MESSAGES, "" );
+	#gettext init
 	$self->{_gettext_object} = Locale::gettext->domain("shutter");
 	$self->{_gettext_object}->dir( $self->{_shutter_root} . "/share/locale" );
 	
@@ -73,6 +72,19 @@ sub new {
 	$self->{_icontheme} = Gtk2::IconTheme->get_default;
 	$self->{_icontheme}->append_search_path($self->{_shutter_root} . "/share/icons");
 
+	#recently used upload tab
+	$self->{_ruu_tab} = 0;
+   #... and details
+	$self->{_ruu_hosting} = 0;
+	$self->{_ruu_places} = 0;
+	$self->{_ruu_u1} = 0;
+
+	#recently used save folder
+	$self->{_rusf} = undef;
+
+	#recently used open folder
+	$self->{_ruof} = undef;
+
 	bless $self, $class;
 	return $self;
 }
@@ -83,6 +95,34 @@ sub get_root {
 	return $self->{_shutter_root};
 }
 
+sub get_pid {
+	my $self = shift;
+	return $self->{_pid};
+}
+
+sub set_pid {
+	my $self = shift;
+	if (@_) {
+		$self->{_pid} = shift;
+	}
+	return $self->{_pid};
+}
+
+sub get_appname {
+	my $self = shift;
+	return $self->{_appname};
+}
+
+sub get_version {
+	my $self = shift;
+	return $self->{_version};
+}
+
+sub get_rev {
+	my $self = shift;
+	return $self->{_rev};
+}
+
 sub get_gettext {
 	my $self = shift;
 	return $self->{_gettext_object};
@@ -127,6 +167,84 @@ sub set_notification_object {
 	return $self->{_notification};
 }
 
+sub get_rusf {
+	my $self = shift;
+	return $self->{_rusf};
+}
+
+sub set_rusf {
+	my $self = shift;
+	if (@_) {
+		$self->{_rusf} = shift;
+	}
+	return $self->{_rusf};
+}
+
+sub get_ruof {
+	my $self = shift;
+	return $self->{_ruof};
+}
+
+sub set_ruof {
+	my $self = shift;
+	if (@_) {
+		$self->{_ruof} = shift;
+	}
+	return $self->{_ruof};
+}
+
+sub get_ruu_tab {
+	my $self = shift;
+	return $self->{_ruu_tab};
+}
+
+sub set_ruu_tab {
+	my $self = shift;
+	if (@_) {
+		$self->{_ruu_tab} = shift;
+	}
+	return $self->{_ruu_tab};
+}
+
+sub get_ruu_hosting {
+	my $self = shift;
+	return $self->{_ruu_hosting};
+}
+
+sub get_ruu_places {
+	my $self = shift;
+	return $self->{_ruu_places};
+}
+
+sub get_ruu_u1 {
+	my $self = shift;
+	return $self->{_ruu_u1};
+}
+
+sub set_ruu_hosting {
+	my $self = shift;
+	if (@_) {
+		$self->{_ruu_hosting} = shift;
+	}
+	return $self->{_ruu_hosting};
+}
+
+sub set_ruu_places {
+	my $self = shift;
+	if (@_) {
+		$self->{_ruu_places} = shift;
+	}
+	return $self->{_ruu_places};
+}
+
+sub set_ruu_u1 {
+	my $self = shift;
+	if (@_) {
+		$self->{_ruu_u1} = shift;
+	}
+	return $self->{_ruu_u1};
+}
+
 sub get_debug {
 	my $self = shift;
 	return $self->{_debug_cparam};
@@ -205,4 +323,11 @@ sub set_start_with {
 	return $self->{_start_with};
 }
 
+sub get_current_monitor {
+	my $self = shift;
+	my ( $window_at_pointer, $x, $y, $mask ) = Gtk2::Gdk->get_default_root_window->get_pointer;
+	my $mon = Gtk2::Gdk::Screen->get_default->get_monitor_geometry( Gtk2::Gdk::Screen->get_default->get_monitor_at_point ($x, $y));
+	return ($mon);
+}
+
 1;
