@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -28,18 +28,11 @@ use utf8;
 use strict;
 use Gtk2;
 
-#Gettext and filename parsing
-use POSIX qw/setlocale strftime/;
-use Locale::gettext;
-
-#define constants
-#--------------------------------------
-use constant TRUE  => 1;
-use constant FALSE => 0;
+#Glib
+use Glib qw/TRUE FALSE/; 
 
 #--------------------------------------
 
-##################public subs##################
 sub new {
 	my $class = shift;
 
@@ -63,18 +56,35 @@ sub create_toolbar {
 	#Icontheme
 	my $icontheme = $self->{_common}->get_theme;
 
+	#button redoshot
+	#--------------------------------------
+	my $image_redoshot = Gtk2::Image->new_from_stock( 'gtk-refresh', 'large-toolbar' );
+	$self->{_redoshot} = Gtk2::ToolButton->new( $image_redoshot, $d->get("Redo") );
+	$self->{_redoshot}->set_is_important (TRUE);
+
+	$tooltips->set_tip( $self->{_redoshot}, $d->get("Redo last screenshot") );
+
+	#--------------------------------------	
+
 	#button selection
 	#--------------------------------------
 	my $image_select;
-	if($icontheme->has_icon('applications-accessories')){
-		$image_select = Gtk2::Image->new_from_icon_name( 'applications-accessories', 'large-toolbar' );		
-	}else{
-		$image_select = Gtk2::Image->new_from_pixbuf(
-			Gtk2::Gdk::Pixbuf->new_from_file_at_size(
-				"$shutter_root/share/shutter/resources/icons/selection.svg", Gtk2::IconSize->lookup('large-toolbar')
-			)
-		);
-	}	
+	eval{
+		my $ccursor_pb = Gtk2::Gdk::Cursor->new('crosshair')->get_image->scale_simple(Gtk2::IconSize->lookup('large-toolbar'), 'bilinear');
+		$image_select = Gtk2::Image->new_from_pixbuf($ccursor_pb);
+	};
+	if($@){
+		if($icontheme->has_icon('applications-accessories')){
+			$image_select = Gtk2::Image->new_from_icon_name( 'applications-accessories', 'large-toolbar' );		
+		}else{
+			$image_select = Gtk2::Image->new_from_pixbuf(
+				Gtk2::Gdk::Pixbuf->new_from_file_at_size(
+					"$shutter_root/share/shutter/resources/icons/selection.svg", Gtk2::IconSize->lookup('large-toolbar')
+				)
+			);
+		}
+	}
+		
 	$self->{_select} = Gtk2::MenuToolButton->new( $image_select, $d->get("Selection") );
 	#The GtkToolButton class uses this property to determine whether 
 	#to show or hide its label when the toolbar style is GTK_TOOLBAR_BOTH_HORIZ. 
@@ -101,8 +111,8 @@ sub create_toolbar {
 	#button window
 	#--------------------------------------
 	my $image_window;
-	if($icontheme->has_icon('preferences-system-windows')){
-		$image_window = Gtk2::Image->new_from_icon_name( 'preferences-system-windows', 'large-toolbar' );		
+	if($icontheme->has_icon('gnome-window-manager')){
+		$image_window = Gtk2::Image->new_from_icon_name( 'gnome-window-manager', 'large-toolbar' );		
 	}else{
 		$image_window = Gtk2::Image->new_from_pixbuf(
 			Gtk2::Gdk::Pixbuf->new_from_file_at_size(
@@ -182,8 +192,8 @@ sub create_toolbar {
 	#button web
 	#--------------------------------------
 	my $image_web;
-	if($icontheme->has_icon('applications-internet')){
-		$image_web = Gtk2::Image->new_from_icon_name( 'applications-internet', 'large-toolbar' );		
+	if($icontheme->has_icon('web-browser')){
+		$image_web = Gtk2::Image->new_from_icon_name( 'web-browser', 'large-toolbar' );		
 	}else{
 		$image_web = Gtk2::Image->new_from_pixbuf(
 				Gtk2::Gdk::Pixbuf->new_from_file_at_size(
@@ -198,6 +208,12 @@ sub create_toolbar {
 
 	#--------------------------------------
 
+	#expanding separator
+	#--------------------------------------	
+	my $expander_r = Gtk2::SeparatorToolItem->new;
+	$expander_r->set_expand(TRUE);
+	$expander_r->set_draw(FALSE);
+
 	#button edit
 	#--------------------------------------
 	my $image_edit;
@@ -229,6 +245,7 @@ sub create_toolbar {
 	#create the toolbar
 	$self->{_toolbar} = Gtk2::Toolbar->new;
 	$self->{_toolbar}->set_show_arrow(FALSE);
+	$self->{_toolbar}->insert( $self->{_redoshot},           -1 );	
 	$self->{_toolbar}->insert( $self->{_select},             -1 );
 	$self->{_toolbar}->insert( Gtk2::SeparatorToolItem->new, -1 );
 	$self->{_toolbar}->insert( $self->{_full},               -1 );
@@ -239,11 +256,75 @@ sub create_toolbar {
 	$self->{_toolbar}->insert( $self->{_tooltip},            -1 );
 	$self->{_toolbar}->insert( Gtk2::SeparatorToolItem->new, -1 );
 	$self->{_toolbar}->insert( $self->{_web},                -1 );
-	$self->{_toolbar}->insert( Gtk2::SeparatorToolItem->new, -1 );
+	#~ $self->{_toolbar}->insert( Gtk2::SeparatorToolItem->new, -1 );
+	$self->{_toolbar}->insert( $expander_r, 				 -1 );
 	$self->{_toolbar}->insert( $self->{_edit},               -1 );
 	$self->{_toolbar}->insert( $self->{_upload},             -1 );
 
 	return $self->{_toolbar};
 }
 
+sub create_btoolbar {
+	my $self = shift;
+
+	my $d            = $self->{_common}->get_gettext;
+	my $window       = $self->{_common}->get_mainwindow;
+	my $shutter_root = $self->{_common}->get_root;
+
+	#Tooltips
+	my $tooltips = $self->{_common}->get_tooltips;
+	
+	#Icontheme
+	my $icontheme = $self->{_common}->get_theme;
+	
+	#expanding separator
+	#--------------------------------------	
+	my $expander_l = Gtk2::SeparatorToolItem->new;
+	$expander_l->set_expand(TRUE);
+	$expander_l->set_draw(FALSE);
+	
+	#--------------------------------------
+	
+	#button back
+	#--------------------------------------
+	my $image_back = Gtk2::Image->new_from_stock( 'gtk-go-back', 'large-toolbar' );
+	$self->{_back} = Gtk2::ToolButton->new( $image_back, '' );
+
+	#--------------------------------------	
+
+	#button home
+	#--------------------------------------
+	my $image_home = Gtk2::Image->new_from_stock( 'gtk-index', 'large-toolbar' );
+	$self->{_home} = Gtk2::ToolButton->new( $image_home, '' );
+
+	#--------------------------------------	
+	
+	#button forward
+	#--------------------------------------
+	my $image_forw = Gtk2::Image->new_from_stock( 'gtk-go-forward', 'large-toolbar' );
+	$self->{_forw} = Gtk2::ToolButton->new( $image_forw, '' );
+
+	#--------------------------------------	
+
+	#expanding separator
+	#--------------------------------------	
+	my $expander_r = Gtk2::SeparatorToolItem->new;
+	$expander_r->set_expand(TRUE);
+	$expander_r->set_draw(FALSE);
+	
+	#--------------------------------------
+	
+	#create the toolbar
+	$self->{_btoolbar} = Gtk2::Toolbar->new;
+	$self->{_btoolbar}->set_no_show_all(TRUE);
+	$self->{_btoolbar}->set_show_arrow(FALSE);
+	$self->{_btoolbar}->insert( $expander_l, -1 );
+	$self->{_btoolbar}->insert( $self->{_back}, -1 );
+	$self->{_btoolbar}->insert( $self->{_home}, -1 );
+	$self->{_btoolbar}->insert( $self->{_forw}, -1 );
+	$self->{_btoolbar}->insert( $expander_r, -1 );
+
+	return $self->{_btoolbar};
+}
+
 1;
