@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -30,18 +30,12 @@ use warnings;
 
 use Gtk2;
 
-#Gettext and filename parsing
-use POSIX qw/setlocale strftime/;
-use Locale::gettext;
-
 #fileparse and tempfile
 use File::Basename qw/ fileparse dirname basename /;
 use File::Temp qw/ tempfile tempdir /;
 
-#define constants
-#--------------------------------------
-use constant TRUE  => 1;
-use constant FALSE => 0;
+#Glib
+use Glib qw/TRUE FALSE/; 
 
 #--------------------------------------
 
@@ -90,14 +84,29 @@ sub save_pixbuf_to_file {
 		eval{
 			$pixbuf->save( $filename, $filetype );
 		};
-	} elsif ( $filetype eq 'svg' ) {	
+	} elsif ( $filetype eq 'pdf' ) {	
 		
-    	my $surface = Cairo::SvgSurface->create($filename, $pixbuf->get_width, $pixbuf->get_height);
+		#0.8? => 72 / 90 dpi		
+    	my $surface = Cairo::PdfSurface->create($filename, $pixbuf->get_width * 0.8, $pixbuf->get_height * 0.8);
     	my $cr = Cairo::Context->create($surface);
+		$cr->scale(0.8, 0.8);
 		Gtk2::Gdk::Cairo::Context::set_source_pixbuf( $cr, $pixbuf, 0, 0 );
 		$cr->paint;
 		$cr->show_page;
+				
+		undef $surface;
+		undef $cr;
+
+	} elsif ( $filetype eq 'svg' ) {	
 		
+		#0.8? => 72 / 90 dpi		
+    	my $surface = Cairo::SvgSurface->create($filename, $pixbuf->get_width * 0.8, $pixbuf->get_height * 0.8);
+    	my $cr = Cairo::Context->create($surface);
+		$cr->scale(0.8, 0.8);
+		Gtk2::Gdk::Cairo::Context::set_source_pixbuf( $cr, $pixbuf, 0, 0 );
+		$cr->paint;
+		$cr->show_page;
+				
 		undef $surface;
 		undef $cr;
 	
