@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -30,10 +30,8 @@ use warnings;
 
 use File::Temp qw/ tempfile tempdir /;
 
-#define constants
-#--------------------------------------
-use constant TRUE  => 1;
-use constant FALSE => 0;
+#Glib
+use Glib qw/TRUE FALSE/; 
 
 #--------------------------------------
 
@@ -294,10 +292,15 @@ sub get_pixbuf_from_drawable {
 		}
 
 		#get the pixbuf from drawable and save the file
-		$pixbuf = Gtk2::Gdk::Pixbuf->get_from_drawable( 
-												$drawable, undef, 
-												$x, $y, 0, 0,
-												$width, $height );
+		eval{
+			if($width > 0 && $height > 0){
+				$pixbuf = Gtk2::Gdk::Pixbuf->get_from_drawable( $drawable, undef, $x, $y, 0, 0, $width, $height );
+			}
+		};
+		if($@){
+			$pixbuf = 5;
+			return FALSE;
+		}
 		
 		#include cursor
 		if($self->{_include_cursor}){
