@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -24,21 +24,19 @@ package Shutter::Screenshot::SelectorAdvanced;
 
 #modules
 #--------------------------------------
-use SelfLoader;
 use utf8;
 use strict;
 use warnings;
 
-use POSIX qw/ floor ceil /;
 use Gnome2::Canvas;
 use Shutter::Screenshot::Main;
+use Shutter::Screenshot::History;
+
 use Data::Dumper;
 our @ISA = qw(Shutter::Screenshot::Main);
 
-#define constants
-#--------------------------------------
-use constant TRUE  => 1;
-use constant FALSE => 0;
+#Glib
+use Glib qw/TRUE FALSE/; 
 
 #--------------------------------------
 
@@ -89,10 +87,6 @@ sub new {
     #~ print "$self dying at\n";
 #~ } 
 
-1;
-
-__DATA__
-
 sub select_advanced {
 	my $self = shift;
 	
@@ -973,18 +967,46 @@ sub take_screenshot {
 	
 	#section not valid
 	} else {
-		
 		$output = 0;
 	}
 
 	#we don't have a useful string for wildcards (e.g. $name)
 	if($output =~ /Gtk2/){
-		$output->{'name'} = $d->get("Selection");
+		$self->{_action_name} = $d->get("Selection");
+	}
+	
+	#set history object
+	if($s){
+		$self->{_history} = Shutter::Screenshot::History->new($self->{_sc}, $self->{_root}, $s->x, $s->y, $s->width, $s->height);
 	}
 	
 	return $output;		
 }
 
+sub redo_capture {
+	my $self = shift;
+	my $output = 3;
+	if(defined $self->{_history}){
+		($output) = $self->get_pixbuf_from_drawable($self->{_history}->get_last_capture);
+	}
+	return $output;
+}	
+
+sub get_history {
+	my $self = shift;
+	return $self->{_history};
+}
+
+sub get_error_text {
+	my $self = shift;
+	return $self->{_error_text};
+}
+
+sub get_action_name {
+	my $self = shift;
+	return $self->{_action_name};
+}
+
 sub quit {
 	my $self = shift;
 	
