@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -24,19 +24,18 @@ package Shutter::Screenshot::Window;
 
 #modules
 #--------------------------------------
-use SelfLoader;
 use utf8;
 use strict;
 use warnings;
 
 use Shutter::Screenshot::Main;
+use Shutter::Screenshot::History;
 use Data::Dumper;
 our @ISA = qw(Shutter::Screenshot::Main);
 
-#define constants
-#--------------------------------------
-use constant TRUE  => 1;
-use constant FALSE => 0;
+#Glib
+use Gtk2;
+use Glib qw/TRUE FALSE/; 
 
 #--------------------------------------
 
@@ -48,11 +47,11 @@ sub new {
 
 	#get params
 	$self->{_include_border} 	= shift;
-	$self->{_xid}  				= shift;   #only used by window_by_xid, undef this when selecting a window
 	$self->{_mode} 				= shift;
 	$self->{_is_hidden}      	= shift;
 	$self->{_show_visible}      = shift;   #show user-visible windows only when selecting a window
 	$self->{_hide_time}			= shift;   #a short timeout to give the server a chance to redraw the area that was obscured
+	$self->{_ignore_type}	    = shift;   #Ignore possibly wrong type hints
 
 	#X11 protocol and XSHAPE ext
 	require X11::Protocol;
@@ -63,8 +62,8 @@ sub new {
 	#main window
 	$self->{_main_gtk_window} 	= $self->{_sc}->get_mainwindow;
 
-	#only used when selecting a window, undef this when selecting a window
-	unless(defined $self->{_xid}){
+	#only used when selecting a window
+	if(defined $self->{_mode} && $self->{_mode} =~ m/(window|section)/ig){
 		
 		#check if compositing is available
 		my $compos = $self->{_main_gtk_window}->get_screen->is_composited;
@@ -269,7 +268,7 @@ sub new {
 					
 			}
 			
-			return FALSE;	
+			return TRUE;	
 		});
 		
 	}
@@ -284,10 +283,6 @@ sub new {
 #~ } 
 #~ 
 
-1;
-
-__DATA__
-
 sub find_wm_window {
 	my $self = shift;
 	my $xid  = shift;
@@ -354,7 +349,12 @@ sub get_shape {
 			$r->width($orig->get_width - $r->x) if($r->x+$r->width > $orig->get_width);
 			$r->height($orig->get_height - $r->y) if($r->y+$r->height > $orig->get_height);	
 			
-			$orig->copy_area ($r->x, $r->y, $r->width, $r->height, $target, $r->x, $r->y);		
+			if($r->x >= 0 && $r->x + $r->width <= $orig->get_width && $r->y >= 0 && $r->y + $r->height <= $orig->get_height){
+				$orig->copy_area ($r->x, $r->y, $r->width, $r->height, $target, $r->x, $r->y);		
+			}else{
+				warn "WARNING: There was an error while calculating the window shape\n";
+				return $orig;
+			}
 		}
 		
 		return $target;
@@ -391,53 +391,6 @@ sub get_window_size {
 	return ( $xp, $yp, $wp, $hp );
 }
 
-sub window_by_xid {
-	my $self = shift;
-
-	my $gdk_window  = Gtk2::Gdk::Window->foreign_new( $self->{_xid} );
-	my $wnck_window = Gnome2::Wnck::Window->get( $self->{_xid} );
-	
-	my $output = 0;
-	if (defined $gdk_window && defined $wnck_window){
-	
-		my ( $xp, $yp, $wp, $hp ) = $self->get_window_size( $wnck_window, $gdk_window, $self->{_include_border} );
-	
-		#focus selected window (maybe it is hidden)
-		$gdk_window->focus(Gtk2->get_current_event_time);
-		Gtk2::Gdk->flush;
-	
-		#A short timeout to give the server a chance to
-		#redraw the area
-		#~ Glib::Timeout->add ($self->{_hide_time}, sub{
-			
-			my ($output_new, $l_cropped, $r_cropped, $t_cropped, $b_cropped) = $self->get_pixbuf_from_drawable( $self->{_root}, $xp, $yp, $wp, $hp);
-	
-			#save return value to current $output variable 
-			#-> ugly but fastest and safest solution now
-			$output = $output_new;	
-	
-			#respect rounded corners of wm decorations (metacity for example - does not work with compiz currently)	
-			if($self->{_x11}{ext_shape} && $self->{_include_border}){
-				$output = $self->get_shape($self->{_xid}, $output, $l_cropped, $r_cropped, $t_cropped, $b_cropped);				
-			}
-	
-			#set name of the captured window
-			#e.g. for use in wildcards
-			if($output =~ /Gtk2/){
-				$output->{'name'} = $wnck_window->get_name;
-			}
-	
-			#~ $self->quit;
-			#~ return FALSE;	
-		#~ });	
-	#~ 
-		#~ Gtk2->main();
-	
-	}
-
-	return $output;
-}
-
 sub update_highlighter {
 	my $self 	= shift;
 	my $x		= shift;
@@ -445,22 +398,33 @@ sub update_highlighter {
 	my $width	= shift;
 	my $height	= shift;
 
-	#and show highlighter window at current cursor position		
-	$self->{_highlighter}->hide;
-
+	#two different methods to hide the window before moving it
+	#(to avoid flicker)
+	if (Gtk2->CHECK_VERSION( 2, 12, 0 )) {
+		$self->{_highlighter}->set_opacity(0);	
+	}else{
+		$self->{_highlighter}->hide;	
+	}
+	
 	if(defined $self->{_c}{'cw'}{'gdk_window'} && defined $self->{_c}{'cw'}{'window'}){
 
 		#Place window and resize it
 		$self->{_highlighter}->move($x-3, $y-3);
 		$self->{_highlighter}->resize($width+6, $height+6);
-	
+		
 		#and show highlighter window at current cursor position		
 		$self->{_highlighter}->show;
+
+		if (Gtk2->CHECK_VERSION( 2, 12, 0 )) {
+			$self->{_notifications_timeout} = Glib::Timeout->add (100, sub{
+				$self->{_highlighter}->set_opacity(1);
+			});		
+		}
 	
 		#save last window objects
 		$self->{_c}{'lw'}{'window'} 	= $self->{_c}{'cw'}{'window'};
 		$self->{_c}{'lw'}{'gdk_window'} = $self->{_c}{'cw'}{'gdk_window'};
-
+			
 	}
 
 }
@@ -756,6 +720,7 @@ sub window {
 	my $self = shift;
 
 	#return value
+	
 	my $output = 5;
 	
 	#current workspace
@@ -853,14 +818,16 @@ sub window {
 					if ( defined $self->{_c}{'lw'} && $self->{_c}{'lw'}{'gdk_window'} ) {
 
 						#focus selected window (maybe it is hidden)
-						$self->{_c}{'lw'}{'gdk_window'}->focus(Gtk2->get_current_event_time);
+						$self->{_c}{'lw'}{'gdk_window'}->focus($event->time);
 						Gtk2::Gdk->flush;						
 
 					#something went wrong here, no window on screen detected	
 					} else {
+						
 						$output = 0;
 						$self->quit;
 						return $output;
+					
 					}
 					
 					#looking for a section of a window?
@@ -918,9 +885,21 @@ sub window {
 						#set name of the captured window
 						#e.g. for use in wildcards
 						if($output =~ /Gtk2/ && defined $self->{_c}{'cw'}{'window'}){
-							$output->{'name'} = $self->{_c}{'cw'}{'window'}->get_name;
+							$self->{_action_name} = $self->{_c}{'cw'}{'window'}->get_name;
 						}
 
+						#set history object
+						$self->{_history} = Shutter::Screenshot::History->new($self->{_sc}, 
+								$self->{_root}, 
+								$self->{_c}{'cw'}{'x'}, 
+								$self->{_c}{'cw'}{'y'},
+								$self->{_c}{'cw'}{'width'},
+								$self->{_c}{'cw'}{'height'},
+								undef,
+								$self->{_c}{'cw'}{'window'}->get_xid,
+								$self->{_c}{'cw'}{'gdk_window'}->get_xid
+						);
+
 						$self->quit;
 						return FALSE;	
 					});	
@@ -959,7 +938,12 @@ sub window {
 
 			#no window with type_hint eq 'menu' detected
 			unless (defined $self->{_c}{'cw'}{'window_region'}){
-				return 2;	
+				if($self->{_ignore_type}){
+					warn "WARNING: No window with type hint 'menu' detected -> window type hint will be ignored, because workaround is enabled\n";
+					$self->find_region_for_window_type( $self->{_root}->XWINDOW );
+				}else{
+					return 2;
+				}
 			}
 
 		}elsif ( ( $self->{_mode} eq "tooltip" || $self->{_mode} eq "tray_tooltip" ) ) {
@@ -969,7 +953,12 @@ sub window {
 
 			#no window with type_hint eq 'tooltip' detected
 			unless (defined $self->{_c}{'cw'}{'window_region'}){
-				return 2;	
+				if($self->{_ignore_type}){
+					warn "WARNING: No window with type hint 'tooltip' detected -> window type hint will be ignored, because workaround is enabled\n";
+					$self->find_region_for_window_type( $self->{_root}->XWINDOW );
+				}else{
+					return 2;
+				}
 			}
 
 		#looking for a section of a window?
@@ -1021,33 +1010,150 @@ sub window {
 		if ( ( $self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ) ) {
 
 			if($output =~ /Gtk2/ && defined $self->{_c}{'cw'}{'window'}){
-				$output->{'name'} = $self->{_c}{'cw'}{'window'}->get_name;
-			}
-
-		}elsif ( ( $self->{_mode} eq "menu" || $self->{_mode} eq "tray_menu" ) ) {
-
-			if($output =~ /Gtk2/){
-				$output->{'name'} = $d->get( "Menu" );
-			}
-
-		}elsif ( ( $self->{_mode} eq "tooltip" || $self->{_mode} eq "tray_tooltip" ) ) {
-
-			if($output =~ /Gtk2/){
-				$output->{'name'} = $d->get( "Tooltip" );
+				$self->{_action_name} = $self->{_c}{'cw'}{'window'}->get_name;
 			}
 
 		}elsif ( ( $self->{_mode} eq "section" || $self->{_mode} eq "tray_section" ) ) {
 
 			if($output =~ /Gtk2/ && defined $self->{_c}{'cw'}{'window'}){
-				$output->{'name'} = $output->{'name'} = $self->{_c}{'cw'}{'window'}->get_name;
+				$self->{_action_name} = $self->{_action_name} = $self->{_c}{'cw'}{'window'}->get_name;
+			}
+
+		}elsif ( ( $self->{_mode} eq "menu" || $self->{_mode} eq "tray_menu" ) ) {
+
+			if($output =~ /Gtk2/){
+				$self->{_action_name} = $d->get( "Menu" );
+			}
+
+		}elsif ( ( $self->{_mode} eq "tooltip" || $self->{_mode} eq "tray_tooltip" ) ) {
+
+			if($output =~ /Gtk2/){
+				$self->{_action_name} = $d->get( "Tooltip" );
 			}
 		
 		}
+
+		if(defined $self->{_c}{'cw'}{'window'} && $self->{_c}{'cw'}{'gdk_window'}){
+	
+			#set history object
+			$self->{_history} = Shutter::Screenshot::History->new($self->{_sc}, 
+				$self->{_root},
+				$self->{_c}{'cw'}{'x'},
+				$self->{_c}{'cw'}{'y'},
+				$self->{_c}{'cw'}{'width'},
+				$self->{_c}{'cw'}{'height'},
+				$self->{_c}{'cw'}{'window_region'},
+				$self->{_c}{'cw'}{'window'}->get_xid,
+				$self->{_c}{'cw'}{'gdk_window'}->get_xid
+			);
+		
+		}else{
+
+			#set history object
+			$self->{_history} = Shutter::Screenshot::History->new($self->{_sc}, 
+				$self->{_root},
+				$self->{_c}{'cw'}{'x'},
+				$self->{_c}{'cw'}{'y'},
+				$self->{_c}{'cw'}{'width'},
+				$self->{_c}{'cw'}{'height'},
+				$self->{_c}{'cw'}{'window_region'},
+			);
+			
+		}
 		
 	}
 	return $output;
 }
 
+sub get_mode {
+	my $self = shift;
+	return $self->{_mode};
+}
+
+sub redo_capture {
+	my $self = shift;
+	my $output = 3;
+	
+	if(defined $self->{_history}){
+		my ($last_drawable, $lxp, $lyp, $lwp, $lhp, $lregion, $wxid, $gxid) = $self->{_history}->get_last_capture;
+		
+		if(defined $gxid && defined $wxid){
+		
+			#create windows
+			my $gdk_window  = Gtk2::Gdk::Window->foreign_new( $gxid );
+			my $wnck_window = Gnome2::Wnck::Window->get( $wxid );
+			
+			if(defined $gdk_window && defined $wnck_window){
+	
+				#store size
+				my ( $xp, $yp, $wp, $hp ) = (0, 0, 0, 0);
+	
+				if($self->{_mode} eq "section" || $self->{_mode} eq "tray_section" ){
+	
+					( $wp, $hp ) = $gdk_window->get_size;
+					( $xp, $yp ) = $gdk_window->get_origin;
+					
+				}elsif($self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ){
+	
+					#get_size of it
+					( $xp, $yp, $wp, $hp ) = $self->get_window_size($wnck_window, $gdk_window, $self->{_include_border});
+								
+				}
+	
+				#focus selected window (maybe it is hidden)
+				$gdk_window->focus(Gtk2->get_current_event_time);
+				Gtk2::Gdk->flush;	
+	
+				#A short timeout to give the server a chance to
+				#redraw the area
+				Glib::Timeout->add ($self->{_hide_time}, sub{
+	
+					my ($output_new, $l_cropped, $r_cropped, $t_cropped, $b_cropped) = $self->get_pixbuf_from_drawable($self->{_root}, $xp, $yp, $wp, $hp);
+	
+					#save return value to current $output variable 
+					#-> ugly but fastest and safest solution now				
+					$output = $output_new;
+	
+					if($self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ){
+						$output = $self->get_shape($gxid, $output, $l_cropped, $r_cropped, $t_cropped, $b_cropped);
+					}
+	
+					$self->quit;
+					return FALSE;	
+				});					
+				
+				Gtk2->main();
+					
+			}else{
+				warn "WARNING: Could not get window with id $gxid\n";
+				$output = 4;
+			}
+		
+		#no xid
+		}else{
+			($output) = $self->get_pixbuf_from_drawable($self->{_history}->get_last_capture);
+		}
+
+	}
+	
+	return $output;
+}	
+
+sub get_history {
+	my $self = shift;
+	return $self->{_history};
+}
+
+sub get_error_text {
+	my $self = shift;
+	return $self->{_error_text};
+}
+
+sub get_action_name {
+	my $self = shift;
+	return $self->{_action_name};
+}
+
 sub quit {
 	my $self = shift;
 	
