@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -24,19 +24,17 @@ package Shutter::Screenshot::Workspace;
 
 #modules
 #--------------------------------------
-use SelfLoader;
 use utf8;
 use strict;
 use warnings;
 
 use Shutter::Screenshot::Main;
+use Shutter::Screenshot::History;
 use Data::Dumper;
 our @ISA = qw(Shutter::Screenshot::Main);
 
-#define constants
-#--------------------------------------
-use constant TRUE  => 1;
-use constant FALSE => 0;
+#Glib
+use Glib qw/TRUE FALSE/; 
 
 #--------------------------------------
 
@@ -60,10 +58,6 @@ sub new {
     #~ print "$self dying at\n";
 #~ } 
 
-1;
-
-__DATA__
-
 sub workspace {
 	my $self = shift;
 
@@ -104,6 +98,7 @@ sub workspace {
 
 	my $output = undef;
 	if ( $self->{_current_monitor_only} || $self->{_gdk_screen}->get_n_monitors <= 1) {
+		
 		($output) = $self->get_pixbuf_from_drawable(
 						$self->get_root_and_current_monitor_geometry
 					);
@@ -117,16 +112,21 @@ sub workspace {
 	#comment copied from gnome-screenshot
 	#http://svn.gnome.org/viewvc/gnome-utils/trunk/gnome-screenshot/screenshot-utils.c?view=markup					
 	} elsif($self->{_gdk_screen}->get_n_monitors > 1) {
+		
 		($output) = $self->get_pixbuf_from_drawable(
 						$self->get_root_and_geometry,
 						$self->get_monitor_region
-					);					
+					);
+										
 	}
 
+	#set history object
+	$self->{_history} = Shutter::Screenshot::History->new($self->{_sc});	
+
 	#set name of the captured workspace
 	#e.g. for use in wildcards
 	if($output =~ /Gtk2/){
-		$output->{'name'} = $self->{_wnck_screen}->get_active_workspace->get_name;
+		$self->{_action_name} = $self->{_wnck_screen}->get_active_workspace->get_name;
 	}
 
 	#metacity etc
@@ -140,4 +140,28 @@ sub workspace {
 	return $output;
 }
 
+sub redo_capture {
+	my $self = shift;
+	my $output = 3;
+	if(defined $self->{_history}){
+		$output = $self->workspace();
+	}
+	return $output;
+}	
+
+sub get_history {
+	my $self = shift;
+	return $self->{_history};
+}
+
+sub get_error_text {
+	my $self = shift;
+	return $self->{_error_text};
+}
+
+sub get_action_name {
+	my $self = shift;
+	return $self->{_action_name};
+}
+
 1;
